#!/usr/bin/ksh
#
# Digital Equipment LG15 Plus
# LPD self-extracting installation script.
#
KIT_COPYRIGHT="Copyright (c) 2003 Hewlett-Packard Company"

KIT_APS=APS
KIT_LPD=LPD
KIT_MINVER="V4.0F"
KIT_TYPE=$KIT_LPD
KIT_PRINTER="Digital Equipment LG15 Plus"
KIT_FILES="lg15plus.pcf Digital_LG15plus.lpd"

function setupInstructions {
    mimimumVersionTest V5.1B
    if [[ $? != 0 ]]
    then
	print "Use lprsetup(8) to create an /etc/printcap file entry, specifying" >&2
	print "the printer type "ln17". This creates the entry for your new printer." >&2
	print "Then edit the printcap entry and apply the following changes:" >&2
	print "" >&2
	print "	:if=/usr/lbin/pcfof +Clg15plus.pcf:\\" >&2
	print "	:of=/usr/lbin/pcfof +Clg15plus.pcf:\\" >&2
	print "	:pw#0:\\" >&2
    else
	print "Use lprsetup(8) to create a new /etc/printcap file entry. Driver" >&2
	print "updates will not impact the current /etc/printcap entries." >&2
    fi
    print "" >&2
    print "For additional information refer to printcap(4) \c" >&2
    if [[ ! -z `find /usr/man/man8/ -name pcfof\*` ]]
    then
	print "and pcfof(8) man pages." >&2
    else
	print "man page." >&2
    fi
}


# Function:
#	askUser Prompt
#
# Description:
#	Prompt for a yes/no response. Default response is no.
#
# Arguments:
#	$1 Prompt Text
#
# Returns:
#	0 User entered yes
#	1 User entered no
#
function askUser {

	print "$1? <Y/N> \c" >&2
	read Response

	case "$Response" in
	[Yy])	return 0
		;;
	[Yy][Ee][Ss])
		return 0
		;;
	*)	return 1
		;;
	esac
}

# Function:
#	wrapMsg Text
#
# Description:
#	Pipe text to fold utility to make sure it will fit
#	within 80 characters.
#
# Arguments:
#	$1 Text, Message Text
#
# Returns:
#	n/a

function wrapMsg {
	print "$1" | fold -s >&2
}

# Function:
#	printLicenseAgreement
#
# Description:
#	Print license agreement
#
# Arguments:
#	None
#
# Returns:
#	Exits when the user does not agree to the terms of the license.

function PrintLicenseAgreement {

    wrapMsg "${KIT_COPYRIGHT}. All rights reserved.\n"

    msg1="                HEWLETT-PACKARD SOFTWARE PRODUCT"
    msg2="                  \"AS IS\" WARRANTY STATEMENT"
    wrapMsg "$msg1\n$msg2\n"

    msg1="DISCLAIMER. TO THE EXTENT ALLOWED BY LOCAL LAW, THIS HP SOFTWARE"
    msg2="PRODUCT (\"SOFTWARE\") IS PROVIDED TO YOU \"AS IS\" WITHOUT WARRANTIES OR"
    msg4="CONDITIONS OF ANY KIND, WHETHER ORAL OR WRITTEN, EXPRESS OR IMPLIED."
    msg5="HP SPECIFICALLY DISCLAIMS ANY IMPLIED WARRANTIES OR CONDITIONS OF"
    msg6="MERCHANTABILITY, SATISFACTORY QUALITY, NON-INFRINGEMENT AND FITNESS"
    msg7="FOR A PARTICULAR PURPOSE. Some countries, states and provinces do not"
    msg8="allow exclusions of implied warranties or conditions, so the above"
    msg9="exclusion may not apply to you. You may have other rights that vary"
    msg10="from country to country, state to state, or province to province."
    wrapMsg "$msg1 $msg2 $msg3 $msg4 $msg5 $msg6 $msg7 $msg8 $msg9 $msg10 \n"

    msg1="LIMITATION OF LIABILITY. EXCEPT TO THE EXTENT PROHIBITED BY LOCAL LAW,"
    msg2="IN NO EVENT WILL HP OR ITS SUBSIDIARIES, AFFILIATES OR SUPPLIERS BE"
    msg3="LIABLE FOR DIRECT, SPECIAL, INCIDENTAL, CONSEQUENTIAL OR OTHER DAMAGES"
    msg4="(INCLUDING LOST PROFIT, LOST DATA, OR DOWNTIME COSTS), ARISING OUT OF"
    msg5="THE USE, INABILITY TO USE, OR THE RESULTS OF USE OF THE SOFTWARE,"
    msg6="WHETHER BASED IN WARRANTY, CONTRACT, TORT OR OTHER LEGAL THEORY, AND"
    msg7="WHETHER OR NOT ADVISED OF THE POSSIBILITY OF SUCH DAMAGES. Your use of"
    msg8="the Software is entirely at your own risk. Should the Software prove"
    msg9="defective, you assume the entire cost of all service, repair or"
    msg10="correction. Some countries, states and provinces do not allow the"
    msg11="exclusion or limitation of liability for incidental or consequential"
    msg12="damages, so the above limitation may not apply to you."
    wrapMsg "$msg1 $msg2 $msg3 $msg4 $msg5 $msg6 $msg7 $msg8 $msg9 $msg10 $msg11 $msg12 \n"

    msg1="NOTE. EXCEPT TO THE EXTENT ALLOWED BY LOCAL LAW, THESE WARRANTY TERMS"
    msg2="DO NOT EXCLUDE, RESTRICT OR MODIFY, AND ARE IN ADDITION TO, THE"
    msg3="MANDATORY STATUTORY RIGHTS APPLICABLE TO THE LICENSE OF THE SOFTWARE"
    msg4="TO YOU."
    wrapMsg "$msg1 $msg2 $msg3 $msg4 \n"

}

# Function:
#	fileVersionTest Version PathFilename
#
# Description:
#	Fetch and compare the file version.
#
# Arguments:
#	$1 Version, The version of the file in this script
#	$2 PathFilename, path/filename of file to test
#
# Returns:
#	0 Script file older than installed file
#	1 Script file the same as installed file
#	2 Script file newier than install file
#
function fileVersionTest {

	new_ver=$(fixVersion $1)

	base=$(basename $2)
	ext=$(basename $2 | cut -f2 -d'.')
	case $ext in
	lpd)
		# Version format: 1.1.2.4
		old_ver=$(grep 'Revision:' $2 | cut -f4 -d\$ | cut -f2 -d: )
		;;
	paf)
		# Version format: APX-1-001 or 100
		old_ver=$(grep 'paf-x-file-version' $2 | cut -f2 -d\= )
		;;
	pcf)
		# Version format: 1.1.2.4
		old_ver=$(grep 'Revision:' $2 | cut -f4 -d\$ | cut -f2 -d: )
		;;
	pfo)
		# The version is not provided in all the files.
		# Version format: 1.0
		old_ver=$(grep 'FileVersion' $2 | cut -f2 -d\: )
		[[ -z $old_ver ]] && old_ver="0.0"
		;;
	[rp]pd)
		# Version format: "1.0"
		old_ver=$(grep '\*FileVersion' $2 | cut -f2 -d\: )
		;;
	*)
		# Lpd print filter?
		old_ver=$(what $2 | tr -s '@' '\n' | grep $base | grep 'Revision:' | cut -f4 -d\$ | cut -f2 -d: )
		;;
	esac

	old_ver=$(fixVersion $old_ver)

	# Are the versions the same?
	if [[ $new_ver = $old_ver ]] 
	then	# Yes
		return 1
	fi

	if [[ $new_ver > $old_ver ]]
	then
		# New file more current
		return 2
	else
		# System file more current
		return 0
	fi
}

# Function:
#	checkSumTest PathFilename CheckSum1 CheckSum2
#
# Description:
#	Fetch and compare the file version.
#
# Arguments:
#	$1 PathFilename, path/filename
#	$2 CheckSum1,  First checksum value generated from the 'sum' command.
#	$3 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Returns:
#	0 Checksum matched
#	1 Checksum error
#
function checkSumTest {

	sum1=`sum $1 | tr -s "  " " " | cut -f 1 -d ' '`
	sum2=`sum $1 | tr -s "  " " " | cut -f 2 -d ' '`

	if [[ $sum1 -ne $2 ]] || [[ $sum2 -ne $3 ]]
	then
		return 1
	else
		return 0
	fi
}

# Function:
#	installTest FileVersion PathFilename CheckSum1 CheckSum2
#
# Description:
#	Test to see if the directory exists and the file
#	uuencoded file is newier than the system file.
#
# Arguments:
#	$1 FileVersion,  File version
#	$2 PathFilename, path/filename
#	$3 CheckSum1,  First checksum value generated from the 'sum' command.
#	$4 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Returns:
#	0 Install file, all tests passed
#	1 Don't install file, one or more tests failed
function installTest {
	mkdir=0

	# Can't install the file if the directory doesn't exist.

	file_name=`basename $2`
	directory=`dirname $2`

	if [[ ! -d $directory ]]
	then
		if [[ $mkdir = 0 ]]
		then
			msg1="Error: File $file_name not installed because"
			msg2="directory $directory doesn't exist."
			wrapMsg "$msg1 $msg2"
			return 1
		else
			mkdir $directory
			chmod 755 $directory
			chown root:system $directory
		fi
	fi

	# If the file does not exist, it's ok to install.
	if [[ ! -e $2 ]]
	then
		return 0
	fi

	fileVersionTest $1 $2
	status=$?

	if [[ $status = 1 ]]
	then
		checkSumTest $2 $3 $4
		if [[ $? = 0 ]]
		then
			# Files are the same, don't install
			wrapMsg "The $file_name system file is current and will not be replaced.\n"
			return 1
		else
			# Versions are the same, but the files are different!
			print "Warning: File versions match but the files are different!">&2
			askUser "Replace $file_name"
			return $?
		fi
	fi

	if [[ $status = 0 ]]
	then
		wrapMsg "The $file_name system file is newier and will not be replaced.\n"
		return 1
 	fi

	return 0
}

# Function:
#	mimimumVersionTest version
#
# Description:
#	Test to see if the minimum application or operating version 
#	requirement is met.
#
# Arguments:
#	$1 Version,    Minimum install version requirement
#
# Returns:
#	0 test passed
#	1 test failed
#
function mimimumVersionTest {

	if [[ $KIT_TYPE = $KIT_APS ]]
	then
		# At this time there isn't a minimum APS requirement.
		return 0 
	fi

	# The only other kit type is LPD, so check the OS version.

	# Note: The version field moves 1 position between Digital UNIX
	#       and Compaq Tru64 UNIX, but is always before (Rev.
	temp=` strings /vmunix | grep '(Rev.' | grep UNIX | cut -f1 -d '(' `

	# The version is the last value
	for x in $temp
	{
	  osver=$x
	}

	# A field test version of the OS might not start with a V. At some
	# point we might need to note the difference, but for now we don't.
	# Modify the version string by replacing the first character with a V.

	temp=$osver
	osver="V$( echo "$osver" | cut -c2- )"

	if [[ $osver < $1 ]]
	then
		return 1
	fi

	return 0
}

# Function:
#	installLpdTest FileVersion PathFilename CheckSum1 CheckSum2
#
# Description:
#	If the file does not currently exist and the minimal install
#	requirements are met, a success status is returned.
#
# Arguments:
#	$1 FileVersion,  File version
#	$2 PathFilename, path/filename
#	$3 CheckSum1,  First checksum value generated from the 'sum' command.
#	$4 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Exits:
#	Exit if the minimum OS requirement is not met.
#
# Returns:
#	0 Install file, all tests passed
#	1 Don't install file, one or more tests failed
#
function installLpdTest {

	file_name=`basename $2`
	file_ext=`print "$file_name" | cut -f2 -d'.'`

	# Perform the OS test after this test. No reason to complain
	# about the os version if the file isn't going to be installed.
	if [[ $file_ext = "lpd" ]]
	then
		# If this is a .lpd file and the base directory doesn't exist
		# return.
		if [[ ! -d `dirname $2` ]]
		then
			msg1="File $file_name is not required for this version of Tru64 UNIX.\n"
			wrapMsg "$msg1"
			return 1
		fi
	fi

	installTest $1 $2 $3 $4
	return $?
}


# Function:
#	installApsTest FileVersion PathFilename CheckSum1 CheckSum2
#
# Description:
#	Test the minimal install requirements for an APS file. 
#
# Arguments:
#	$1 File version, File version
#	$2 PathFilename, path/filename
#	$3 CheckSum1,  First checksum value generated from the 'sum' command.
#	$4 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Returns:
#	0 Install file, all tests passed
#	1 Don't install file, one or more tests failed
#

function installApsTest {

	installTest $1 $2 $3 $4
	return $?
}

# Function:
#	fixVersion Version
#
# Description:
#	Remove unwanted characters.
#	Aps two version formats are converted to a common format.
#
# Arguments:
#	$1 Version, Version string
#
# Returns:
#	The updated version string.
#
function fixVersion {

	# Remove quotes, tabs, and spaces
	ver=$(echo $1 | tr -d "\"\t ")

	# Set null strings to version 0
	if [[ -z $ver ]]
	then
		ver=0
	fi

	# If the version starts with 'a', convert
	# a???-x-xxx to xxxx
	case $ver in
	[Aa]*)	;;
	[0123456789]*)
		# Return the version
		print "$ver"
		return
		;;
	*)	# Don't know what we found so return a version of 0.
		print "0.0"
		;;
	esac

	# To compare version 100 to apx-?-??? convert
	# apx-1-001 to 1001
	# apx-1-2   to 1002
	part1=$(echo "$ver" | cut -f2 -d\-)
	part2=$(echo "$ver" | cut -f3 -d\-)

	ver=$(printf "%s%.3d" $part1 $part2)

	# Return the version
	print "$ver"
	return
}

# Function:
#	preInstall FileVersion PathFilename CheckSum1 CheckSum2
#
# Description:
#	Determine if this is an APS or LPD install and call the
#	appropriate function.
#
# Arguments:
#	$1 FileVersion,  File version
#	$2 PathFilename, path/filename
#	$3 CheckSum1,  First checksum value generated from the 'sum' command.
#	$4 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Returns:
#	0 Install file
#	1 Don't install file
#
function preInstall {

	status=1

	if [[ $KIT_TYPE = $KIT_LPD ]] 
	then
		installLpdTest $1 $2 $3 $4
		status=$?
	fi

	if [[ $KIT_TYPE = $KIT_APS ]] 
	then
		installApsTest $1 $2 $3 $4
		status=$?
	fi

	# On install status, backup existing file
	# if it exists
	if [[ $status = 0 ]]
	then
		if [[ -e $2 ]]
		then
			# format = filename_yyyymmmdd_hh:mm:ss
			backup=$2_$(date +"b%d_%T")
			mv $2 $backup
			wrapMsg "Backup file $backup created."

			# Return the name of the backup file
			print "$backup"
		fi
	fi
	return $status
}

# Function:
#	postInstall BackupFile Owner Group Protection FileName CheckSum1 CheckSum2
#
# Description:
#	After the file has been installed verify the file checksum. If
#	the checksum is ok, set the file owner and protection.
#
#	Notify the user of a checksum error and prompt to remove the file.
#
# Arguments:
#	$1 BackupFile, Name of the backup file
#	$2 Owner,      File owner for chown command
#	$3 Group,      Group owner for chgrp command
#	$4 Protection, File protections number, eg 644, for chmod command
#	$5 FileName,   Installed file path/filename
#	$6 CheckSum1,  First checksum value generated from the 'sum' command.
#	$7 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Returns:
#	None
#
function postInstall {

	chown $2:$3 $5
	chmod $4 $5

	checkSumTest $5 $6 $7
	if [[ $? != 0 ]]
	then
		wrapMsg "Install checksum error on file $5!"

		if [[ ! -z $1 ]]
		then
			askUser "Restore the backup file"
		else
			askUser "Delete the file $5"
		fi

		if [[ $? = 0 ]]
		then 
			rm $5
			if [[ ! -z $1 ]]
			then
				mv $1 $5
				wrapMsg "Backup file restored.\n"
			else
				wrapMsg "File $5 deleted.\n"
			fi
		fi
	else
		wrapMsg "File $5 installed.\n"
		FileInstalled=1
	fi
	return
}

# Function:
#	doHelp
#
# Description:
#	Display the install script options.
#
# Arguments:
#	None
#
# Returns:
#	None
#
function doHelp {
	print "Synopsis: $(basename $0) -option" >&2
	print "" >&2
	print "Options:  -i Install files" >&2
	print "          -p Printer configuration instructions" >&2
	print "" >&2
	return
}

#
# Program
#

typeset -xi FileInstalled=0

# Identify the program

if [[ $KIT_TYPE = $KIT_LPD ]]
then
	print "LPD \c"

elif [[ $KIT_TYPE = $KIT_APS ]]
then
	print "Advanced Printing Software \c"
fi

print "installation kit for: $KIT_PRINTER\n"


# When no arguments are provided, display the help text and exit.
if [[  $# = 0 ]]
then
	doHelp
	exit 0
fi

while getopts :hip opt
do
        case $opt in
	h)	doHelp
		exit 0
		;;
	i)	# Install, fall out of case statement
		;;
	p)	# Print post-install setup instructions
		setupInstructions
		exit 0
		;;
	\?)	doHelp
		exit 0
                ;;
        esac
done

UserName=`whoami`

if [[ $UserName != "root" ]]
then
	print "You must be root to run this program."
	exit 1
fi

mimimumVersionTest $KIT_MINVER
if [[ $? != 0 ]]
then
	msg1="This installation requires a minimum"
	msg2="operating system version of $1."
	wrapMsg "$msg1 $msg2"
	exit 1
fi

subset_name=UNKNOWN
if [[ $KIT_TYPE = $KIT_LPD ]]
then
	subset_name=OSFPRINT
elif [[ $KIT_TYPE = $KIT_APS ]]
then
	subset_name=APXBASE
else
	print "Error: Unknown kit type."
	exit 1
fi

if [ ! -e /usr/.smdb./$subset_name*.lk ]
then
	print "The update requires the $subset_name subset to be installed."
	exit 1
fi

print "This kit contains the following files:\n"

echo "$KIT_FILES" | fold -s
print ""

PRESS_ENTER='Press ENTER to continue'

printf "$PRESS_ENTER"
read temp

PrintLicenseAgreement 2>&1 | pg -e -p "$PRESS_ENTER" >&2

askUser "Do you accept the terms in the license agreement"
if [[ $? != 0 ]]
then
	# User did not accept license agreement.
	print "No files were installed."
	exit 1
fi
print "\n\n"

#--- uuencoded files ---
backup_file=$(preInstall "1.1.4.1" /usr/lbin/pcf/lg15plus.pcf 27818 2)
if [[ $? = 0 ]]
then
uudecode << 'EndOfEncodedFile'
begin 644 /usr/lbin/pcf/lg15plus.pcf
M(2!`*",I)%)#4V9I;&4Z(&QG,35P;'5S+G!C9BQV("0@)%)E=FES:6]N.B`Q
M+C$N-"XQ("0@)$1A=&4Z(#(P,#$O,#DO,3D@,3@Z,#0Z,3`@)`HA"B$@3D]4
M13H@1&\@;F]T(&UO9&EF>2!T:&ES(&9I;&4A"B$@("`@("`@5&AI<R!F:6QE
M('=I;&P@8F4@<F5P;&%C960@=VAE;B!T:&4@;W!E<F%T:6YG('-Y<W1E;2!I
M<R!U<&1A=&5D+@HA*PHA($UO9&5L3F%M93H@0V]M<&%Q($QI;F4@36%T<FEX
M($Q',35P;'5S"B$*(2!&96%T=7)E<SH*(0HA"4QA;F1S8V%P92!M;V1E('!R
M:6YT<R!I;B!P;W)T<F%I="!U<VEN9R!A(&-O;7!R97-S960@9F]N="X@"B$)
M16EG:'0@8FET(&-H87)A8W1E<G,@87)E(&UA<'!E9"!T;R!)4T\@3&%T:6XM
M,2X*(0HA($YO=&5S("\@4F5S=')I8W1I;VYS.@HA"B$@2&%R9'=A<F4@4V5T
M=7`Z"B$*(2T*9F]R;6%T('9E<G-I;VXZ,#`S"B$@1FEL=&5R(%1Y<&5S.B!0
M4$PL(%!#3"P@05-#24DL(%A&"F9I;'1E<B!T>7!E.E!03`IA=71O('!A<W-T
M:')U.ED*<F5S970Z7#`S,ULA<`IR97-E="!D96QA>3HP"FEN:70@<V5Q.EPP
M,S-;/S=L7#`S,RU!7#`S,WX*:6YI="!D96QA>3HP"G1E<FT@<V5Q.EPP,S-;
M(7`*=&5R;2!D96QA>3HP"F%U=&\@<F5S970Z3@IF;VYT(&9I;&4@<')E9FEX
M.@IF;VYT(&9I;&4@<W5F9FEX.@IF;VYT(&9I;&4Z"F9O;G0@9FEL92!L:6YE
M<SH*<')E9FEX('!A9V4Q.@IP<F5F:7@@<&%G93$@;&EN97,Z"G!R969I>"!P
M86=E;CH*<')E9FEX('!A9V5N(&QI;F5S.@IS=69F:7@@<&%G93$Z"G-U9F9I
M>"!P86=E,2!A="!L:6YE.@IS=69F:7@@<&%G96XZ"G-U9F9I>"!P86=E;B!A
M="!L:6YE.@IC:&%R86-T97(@;6%P(&9I;&4Z"F]R:65N=&%T:6]N.G!O<G1R
M86ET"G!O<G1R86ET.EPP,S-;,'=<,#,S6S8V=`IP;W)T<F%I="!L:6YE<SHV
M-@IP;W)T<F%I="!C;VQU;6YS.C`*;&%N9'-C87!E.EPP,S-;,W=<,#,S6S8V
M=`IL86YD<V-A<&4@;&EN97,Z-C8*;&%N9'-C87!E(&-O;'5M;G,Z,`IL86YD
M<V-A<&4@=&AR97-H;VQD.@IW<F%P(&QI;F4Z3@IW<F%P(&QI;F4@;6%R:SH*
M;F5W;&EN93I<,#$U7#`Q,@IR971U<FXZ7#`Q-0IN97=P86=E.EPP,35<,#$T
M"B%E;VIN97=P86=E.@IB86-K<W!A8V4Z7#`Q,`IT86(Z7#`Q,0IT86(@=VED
M=&@Z.`IT86(@97AP86YS:6]N.DX*:6YD96YT.C`*8F%N;F5R('5T:6QI='DZ
M"G1R86EL97(@=71I;&ET>3H*8F%N;F5R('1R87DZ"G1R86EL97(@=')A>3H*
M:6YP=70@=')A>2!D969A=6QT.@IO=71P=70@=')A>2!D969A=6QT.@IS:61E
M<SHQ"G-I;7!L97@Z"G-I;7!L97@@='5M8FQE.@ID=7!L97@Z"F1U<&QE>"!T
'=6UB;&4Z"G!L
`
end
EndOfEncodedFile
postInstall "$backup_file" bin bin 644 /usr/lbin/pcf/lg15plus.pcf 27818 2
fi

backup_file=$(preInstall "1.1.4.1" /usr/lbin/lprsetup/Digital_LG15plus.lpd 37405 1)
if [[ $? = 0 ]]
then
uudecode << 'EndOfEncodedFile'
begin 644 /usr/lbin/lprsetup/Digital_LG15plus.lpd
M(R!`*",I)%)#4V9I;&4Z($1I9VET86Q?3$<Q-7!L=7,N;'!D+'8@)"`D4F5V
M:7-I;VXZ(#$N,2XT+C$@)"`D1&%T93H@,C`P,2\P.2\Q-R`Q-#HP-3HP,"`D
M"G!R:6YT97(Z7`H@("`@.E!./41I9VET86P@3$<Q-2!0;'5S.EP*("`@(#IB
M<CTY-C`P.EP*("`@(#IF8STP,3<W-S<W.EP*("`@(#IF<STP,SI<"B`@("`Z
M:68]+W5S<B]L8FEN+W!C9F]F("M#;&<Q-7!L=7,N<&-F.EP*("`@(#IO9CTO
M=7-R+VQB:6XO<&-F;V8@*T-L9S$U<&QU<RYP8V8Z7`H@("`@.GAF/2]U<W(O
M;&)I;B]X9CI<"B`@("`Z;7@],#I<"B`@("`Z<&P]-C8Z7`H@("`@.G!W/3`Z
M7`H@("`@.G)W/6]N.EP*("`@(#IX8STP,3<W-S<W.EP*("`@(#IX<STP-#0P
M,#`Z7`H@("`@.E!$/5QN7`I4:&4@1&EG:71A;"!,1S$U(%!L=7,@:7,@82`Q
M-3`P(&QI;F5S('!E<B!M:6YU=&4@;&EN92!M871R:7@@<')I;G1E<BY<;EQN
".@HP
`
end
EndOfEncodedFile
postInstall "$backup_file" bin bin 644 /usr/lbin/lprsetup/Digital_LG15plus.lpd 37405 1
fi

mimimumVersionTest V5.1B
if [[ $? = 0 ]] && [[ $FileInstalled > 0 ]]
then
    if [[ -z $(/usr/sbin/lprsetup -c update) ]]
    then
        print "File /etc/lprsetup.dat was backed up then updated."
    fi
fi
exit 0
